/*
 * DrawUtils.java
 *
 * Created on 27. Mai 2006, 04:58
 */

package java2D1zusatz;

import com.sun.image.codec.jpeg.JPEGCodec;
import com.sun.image.codec.jpeg.JPEGImageDecoder;
import java.awt.Color;
import java.awt.GradientPaint;
import java.awt.Paint;
import java.awt.Shape;
import java.awt.TexturePaint;
import java.awt.geom.Arc2D;
import java.awt.geom.Ellipse2D;
import java.awt.geom.GeneralPath;
import java.awt.geom.Rectangle2D;
import java.awt.geom.RoundRectangle2D;
import java.awt.image.BufferedImage;
import java.io.InputStream;

/**
 *
 * @author Arnd
 */
public class DrawUtils {
    private static DrawUtils ref;
    private final Paint redPaint = java.awt.Color.RED;
    private final Paint bluePaint = java.awt.Color.BLUE;
    private final Paint gradientPaint = new GradientPaint(0,0,Color.BLACK,150,150,Color.WHITE,false);
    private Paint textPaint;
    
    private final Shape roundRect = new RoundRectangle2D.Double(0,0,150,150,10,10);
    private final Shape rect = new Rectangle2D.Double(0,0,150.0,150.0);
    private final Shape circle = new Ellipse2D.Double(0,0,150.0,150.0);
    private final Shape arc = new Arc2D.Double( 0,0,150,150,90,270,Arc2D.PIE );
    private Shape generalPath;
    
    /** Creates a new instance of DrawUtils */
    private DrawUtils() {
        BufferedImage texture = null;
        try {
            InputStream in=this.getClass().getResourceAsStream("./mauer.jpg");
            JPEGImageDecoder decoder = JPEGCodec.createJPEGDecoder(in);
            texture = decoder.decodeAsBufferedImage();
            in.close();
        } catch (Exception e) {
            e.printStackTrace();
        };
        setTextPaint(new TexturePaint(texture, (Rectangle2D) getRect()));
    }
    
    public static synchronized DrawUtils getInstance() {
        if (ref == null) {
            ref = new DrawUtils();
        }
        return ref;
    }
    
    public Paint getRedPaint() {
        return redPaint;
    }
    
    public Paint getBluePaint() {
        return bluePaint;
    }
    
    
    public Paint getGradientPaint() {
        return gradientPaint;
    }
    
    public Paint getTextPaint() {
        return textPaint;
    }
    
    private void setTextPaint(Paint textPaint) {
        this.textPaint = textPaint;
    }
    
    public Shape getRoundRect() {
        return roundRect;
    }
    
    public Shape getRect() {
        return rect;
    }
    
    
    public Shape getCircle() {
        return circle;
    }
    
    
    public Shape getArc() {
        return arc;
    }
    
    public Shape getGeneralPath() {
        if (generalPath==null) {
            GeneralPath gp = new GeneralPath();
            gp.moveTo(116.0f,93.0f);
            
            gp.lineTo(    97.0f,2.0f     );
            gp.lineTo(    59.0f,92.0f    );
            gp.lineTo(    35.0f,1.0f     );
            gp.lineTo(    10.0f,90.0f    );
            gp.lineTo(    140.0f,1.0f    );
            gp.lineTo(    60.0f,120.0f   );
            gp.lineTo(     2.0f,1.0f     );
            
            gp.closePath();
            
            generalPath = gp;
            
            
            
        }
        return generalPath;
    }
    
    
    
    
}
