
package java2D1zusatz;

import java.awt.Canvas;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.GradientPaint;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.RenderingHints;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.awt.geom.Rectangle2D;
import java.util.Iterator;
import javax.swing.*;
import java.awt.geom.*;
import java.awt.image.BufferedImage;
import java.util.List;

/**
 * Komponente, auf der gezeichnet wird
 * @author arnd
 */
public class RenderCanvas extends Canvas {
    
    private RenderingHints qualityHints;
    private Graphics2D graphics2D;
    private ObjectRenderer objectRenderer;
    private CanvasModel cModel;
    private int x;
    private int y;
    private PainterView v;
    
    RenderCanvas(CanvasModel cm, PainterView v) {
        cModel = cm;
        this.v = v;
        setBackground(Color.black);
        this.objectRenderer = new ObjectRenderer();
        this.qualityHints = new RenderingHints(null);
        
        
        addMouseListener(new MouseAdapter() {
            public void mousePressed(MouseEvent e) {
                
                x = e.getX();
                y = e.getY();
                if (State.getCurrentMode()==State.MODE_ADD) {
                    AffineTransform pos = AffineTransform.getTranslateInstance(x,y);
                    pos.rotate(State.getAngle()*Math.PI/180, 75, 75);
                    GeometricObject go = new GeometricObject(State.getShapeOption(),State.getFillOption(),  pos);
                    cModel.addObject(go);
                    
                    if(State.isAntialiasingEnabled()) {
                        qualityHints.put(RenderingHints.KEY_ANTIALIASING,RenderingHints.VALUE_ANTIALIAS_ON);
                    } else {
                        qualityHints.put(RenderingHints.KEY_ANTIALIASING,RenderingHints.VALUE_ANTIALIAS_OFF);
                    }
                    if(State.isDitheringEnabled()) {
                        qualityHints.put(RenderingHints.KEY_DITHERING,RenderingHints.VALUE_DITHER_ENABLE);
                    } else {
                        qualityHints.put(RenderingHints.KEY_DITHERING, RenderingHints.VALUE_DITHER_DISABLE);
                    }
                }
                repaint();
            }
        });
        
        
    }
    
    
    public void paint(Graphics g) {
        //Cast Graphics g to Graphics2D graphics2D
        graphics2D = (Graphics2D) g;
        
        //RenderingHints setzen
        graphics2D.setRenderingHints(qualityHints);
        
        
        List objects = cModel.getObjects();
        Iterator it = objects.iterator();
        while (it.hasNext()) {
            GeometricObject go = (GeometricObject)it.next();
            
            if (State.getCurrentMode() == State.MODE_SELECT) {
                //Prfe, ob Objekt Bereich des Mauszeigers liegt

                double[] matrix = new double[9]; 
                go.getTransform().getMatrix(matrix);
                AffineTransform at = new AffineTransform(matrix);
                try {
                    at = at.createInverse();      
                } catch (Exception e) {
                    e.printStackTrace();
                }
                Point2D src = new Point2D.Double(x,y);
                Point2D dst = new Point2D.Double();
                
                at.transform(src,dst);
                
                int xt = (int)dst.getX();
                int yt = (int)dst.getY();
                
                if (go.getShape().contains(xt,yt)) {
                    //wenn ja, in State als selektiertes Objekt setzen
                    State.setSelectedObject(go);
                }
                
                
            }
            this.objectRenderer.renderObject(graphics2D, go);
        }
        //Wenn selektiertes Objekt ungleich null, Bounding Box um Objekt rendern
        GeometricObject selectedO = State.getSelectedObject();
        if (State.getCurrentMode()==State.MODE_SELECT&&selectedO !=null) {
            graphics2D.setColor(Color.GREEN);
            graphics2D.setStroke(new java.awt.BasicStroke(5));
            
            graphics2D.setTransform(selectedO.getTransform());
            
            graphics2D.draw(selectedO.getShape().getBounds2D());
            //showInformation about selectedObject
            v.updateView();
        }
        
    }
    
    
    public Dimension getPreferredSize() {
        return new Dimension(400,400);
    }
}
